@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 
-__title__ = 'djangorestframework-jwt-v4'
-__version__ = '0.0.1'
-__author__ = 'Pedro Barbosa'
+__title__ = 'djangorestframework-jwt-4'
+__version__ = '1.12.0'
+__author__ = 'José Padilla'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2014-2017 Blimp LLC'
 
